<?php

namespace Prajna\Appointment\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Prajna\Appointment\Actions\AppointmentAction;
use Prajna\Appointment\Http\Requests\AppointmentActionRequest;
use Prajna\Appointment\Http\Resources\AppointmentResource;
use Prajna\Appointment\Models\Appointment;

/**
 * Admin web controller class.
 */
class AppointmentActionController extends BaseController
{

    /**
     * Action controller function for appointment.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AppointmentActionRequest $request, Appointment $appointment, $action)
    {
        try {
            $request = $request->all();
            $appointment = AppointmentAction::run($action, $appointment, $request);

            $data = new AppointmentResource($appointment);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('appointment::appointment.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('appointment/appointment/' . $appointment->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('appointment/appointment/' . $appointment->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
