<?php

namespace Prajna\Appointment\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Prajna\Appointment\Http\Requests\AppointmentActionsRequest;
use Prajna\Appointment\Actions\AppointmentActions;

/**
 * Admin web controller class.
 */
class AppointmentActionsController extends BaseController
{

    /**
     * Action controller function for appointment.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AppointmentActionsRequest $request, $action)
    {
        try {
            $appointment = AppointmentActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('appointment::appointment.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('appointment/appointment/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('appointment/appointment/' . $action))
                ->redirect();
        }
    }
}
