<?php

namespace Prajna\Appointment\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Prajna\Appointment\Http\Resources\AppointmentResource;
use Prajna\Appointment\Http\Resources\AppointmentsCollection;
use Prajna\Appointment\Scopes\AppointmentPublicScope;
use Prajna\Appointment\Models\Appointment;

class AppointmentPublicController extends BaseController
{

    /**
     * Show appointment's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Appointment::pushScope(new RequestScope())
            ->pushScope(new AppointmentPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $appointments = new AppointmentsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('appointment::appointment.names'))
            ->view('appointment::public.appointment.index')
            ->data(compact('appointments', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show appointment.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Appointment::findBySlug($slug);
        $data = new AppointmentResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('appointment::appointment.name'))
            ->view('appointment::public.appointment.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
