<?php

namespace Prajna\Appointment\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Prajna\Appointment\Events\AppointmentAction as AppointmentActionEvent;
use Prajna\Appointment\Notifications\AppointmentAction as AppointmentActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AppointmentAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AppointmentActionEvent.
     *
     * @param   AppointmentActionEvent  $event
     * @return mixed
     */
    public function handle(AppointmentActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $appointment.
     *
     * @param   AppointmentActionEvent  $event
     * @return void
     */
    public function create(AppointmentActionEvent $event)
    {
        $client = $event->appointment->client;
        Notification::send($client, new AppointmentActionNotification($event));
    }

    /**
     * Handle the AppointmentActionEvent as a listener.
     *
     * @param   AppointmentActionEvent  $event
     * @return mixed
     */
    public function asListener(AppointmentActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AppointmentActionEvent  $event
     * @return bool
     */
    private function isAllowed(AppointmentActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
