<?php
namespace Prajna\Appointment\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Prajna\Appointment\Events\AppointmentAction as AppointmentActionEvent;
use Prajna\Appointment\Models\Appointment;

class AppointmentAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $appointment;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AppointmentActionEvent $appointment
     */
    public function __construct(AppointmentActionEvent $appointment)
    {
        $this->action = $event->action;
        $this->appointment = $appointment;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Appointment Approved - ' . config('app.name'))
            ->view('appointment::appointment.email.action', ['data' => $this->appointment]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
