<?php

namespace Prajna\Appointment\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Prajna\Appointment\Models\Appointment;

class AppointmentPolicy
{

    use AppointmentAction;

    /**
     * Determine if the given user can view the appointment.
     *
     * @param Authenticatable $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function view(Authenticatable $user, Appointment $appointment)
    {
        if ($authUser->canDo('appointment.appointment.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $appointment->is_owner;
    }

    /**
     * Determine if the given user can create a appointment.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('appointment.appointment.create');
    }

    /**
     * Determine if the given user can update the given appointment.
     *
     * @param Authenticatable $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function update(Authenticatable $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.edit') && $user->isAdmin()) {
            return true;
        }

        return $appointment->is_owner;
    }

    /**
     * Determine if the given user can delete the given appointment.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Appointment $appointment)
    {
        return $appointment->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
